@@ -3,7 +3,6 @@ import cv2
 def sketch(image):
 
   gray_image = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
-  cv2.imshow("President Trump", gray_image)
 
   inverted_image = 255 - gray_image
   blurred = cv2.GaussianBlur(inverted_image, ksize=(21, 21),sigmaX=0, sigmaY=0)
@@ -13,6 +12,6 @@ def sketch(image):
   cv2.imshow("Sketch", pencil_sketch)
 
   cv2.imshow("pencil sketch", pencil_sketch)
-  cv2.imwrite("trump.png",pencil_sketch)
+  cv2.imwrite("sketch.png",pencil_sketch)
   cv2.waitKey(0)
 
